==> landers.angular-1.0.92.tgz: package/src/utils/factory-listitem.js <==
;angular.module('Landers.angular')
    .factory('Listitem', ['Flat', function (Flat){
        var _class = {
            list:'list',
            item:'list-item',
            checked:'checked',
            actived:'active',
            head:'list-head',
            checker:'checker'
        };
        var data = function(scope, datakey, index, data_or_key){
            if (typeof data_or_key === 'undefined') {
                return Flat.get(scope, [datakey, index].join('.'));
            } else {
                if (angular.isString(data_or_key)) {
                    var dat = Flat.get(scope, [datakey, index].join('.')) || {};
                    return dat[data_or_key];
                } else {
                    Flat.set(scope, [datakey, index].join('.'), data);
                }
            }
        };
        var update = function(scope, datakey, index, data, field) {
            var _update = function(_field, _data){
                var _datakey = [datakey, index, _field];
                Flat.set(scope, _datakey.join('.'), _data);
            };
            if (field) {
                _update(field, data);
            } else {
                for (var fieldKey in data){
                    _update(fieldKey, data[fieldKey]);
                }
            }
            if (!scope.$$phase) scope.$apply();
        };
        var remove = function(scope, datakey, index){
            if ( index >= 0) {
                var data = Flat.get(scope, datakey);
                data.splice(index, 1);
                if (!scope.$$phase) scope.$apply();
            }
        };
        function listitem(lister, $event) {
            var $item = (function(){
                if (angular.isElement($event)) {
                    return $event;
                } else {
                    $event = angular.element($event.target);
                    return $event.closest('.' + _class.item);
                }
            })();
            this.get = function(){
                return $item;
            };
            this.getlist = function() {
                return $item.closest('.' + _class.list);
            };
            this.index = function(){
                var $head = $item.siblings('.' + _class.head);
                var index = $item.index();
                return $head.length ? index - 1 : index;
            };
            this.data = function(data_or_key) {
                var index = this.index();
                return data(lister.scope, lister.datakey, index, data_or_key);
            };
            this.update = function(data, field){
                var index = this.index();
                update(lister.scope, lister.datakey, index, data, field);
            };
            this.remove = function() {
                var index = this.index();
                remove(lister.scope, lister.datakey, index);
            };
            this.toggleClass = function(is, classname){
                if (is) {
                    $item.addClass(classname);
                } else {
                    $item.removeClass(classname);
                }
                return this;
            };
            this.active = function(is_active){
                return this.toggleClass(is_active, _class.actived);
            };
            this.select = function(is_check){
                return this.toggleClass(is_check, _class.checked);
            };
        }
        return {
            make:function(scope, $event) {
                return new listitem(scope, $event);
            },
            _class:_class,
            data:data,
            update:update,
            remove:remove
        };
    }]);

==> landers.angular-2.0.24.tgz: package/src/utils/factory-listitem.js <==
;angular.module('Landers.angular')
    .factory('Listitem', ['Flat', function (Flat){
        var _class = {
            list:'list',
            item:'list-item',
            checked:'checked',
            actived:'active',
            head:'list-head',
            checker:'checker'
        };
        var data = function(scope, datakey, index, data_or_key){
            if (typeof data_or_key === 'undefined') {
                return Flat.get(scope, [datakey, index].join('.'));
            } else {
                if (angular.isString(data_or_key)) {
                    var dat = Flat.get(scope, [datakey, index].join('.')) || {};
                    return dat[data_or_key];
                } else {
                    Flat.set(scope, [datakey, index].join('.'), data);
                }
            }
        };
        var update = function(scope, datakey, index, data, field) {
            var _update = function(_field, _data){
                var _datakey = [datakey, index, _field];
                Flat.set(scope, _datakey.join('.'), _data);
            };
            if (field) {
                _update(field, data);
            } else {
                for (var fieldKey in data){
                    _update(fieldKey, data[fieldKey]);
                }
            }
            if (!scope.$$phase) scope.$apply();
        };
        var remove = function(scope, datakey, index){
            if ( index >= 0) {
                var data = Flat.get(scope, datakey);
                data.splice(index, 1);
                if (!scope.$$phase) scope.$apply();
            }
        };
        function Listitem(lister, $event) {
            var $item = (function(){
                if (angular.isElement($event)) {
                    return $event;
                } else {
                    $event = angular.element($event.target);
                    return $event.closest('.' + _class.item);
                }
            })();
            this.get = function(){
                return $item;
            };
            this.getlist = function() {
                return $item.closest('.' + _class.list);
            };
            this.index = function(){
                var $head = $item.siblings('.' + _class.head);
                var index = $item.index();
                return $head.length ? index - 1 : index;
            };
            this.data = function(data_or_key) {
                var index = this.index();
                return data(lister.scope, lister.datakey, index, data_or_key);
            };
            this.update = function(data, field){
                var index = this.index();
                update(lister.scope, lister.datakey, index, data, field);
            };
            this.remove = function() {
                var index = this.index();
                remove(lister.scope, lister.datakey, index);
            };
            this.toggleClass = function(is, classname){
                if (is) {
                    $item.addClass(classname);
                } else {
                    $item.removeClass(classname);
                }
                return this;
            };
            this.active = function(is_active){
                return this.toggleClass(is_active, _class.actived);
            };
            this.select = function(is_check){
                return this.toggleClass(is_check, _class.checked);
            };
        }
        return {
            make:function(lister, $event) {
                return new Listitem(lister, $event);
            },
            _class:_class,
            data:data,
            update:update,
            remove:remove
        };
    }]);
